@@ -28,10 +28,9 @@ NotImplementedError if they cannot handle a certain part
 """
 
 
-PLUGIN_ENTRY_POINT = 'rdf.plugins.sparqleval'
-
-
+PLUGIN_ENTRY_POINT = "rdf.plugins.sparqleval"
 
+import sys
 from . import parser
 from . import operators
 from . import parserutils
@@ -42,10 +41,16 @@ assert parser
 assert operators
 assert parserutils
 
-try:
-    from pkg_resources import iter_entry_points
-except ImportError:
-    pass  # TODO: log a message
+if sys.version_info < (3, 8):
+    from importlib_metadata import entry_points
 else:
-    for ep in iter_entry_points(PLUGIN_ENTRY_POINT):
+    from importlib.metadata import entry_points
+
+all_entry_points = entry_points()
+if isinstance(all_entry_points, dict):
+    # Prior to Python 3.10, this returns a dict instead of the selection interface
+    for ep in all_entry_points.get(PLUGIN_ENTRY_POINT, []):
+        CUSTOM_EVALS[ep.name] = ep.load()
+else:
+    for ep in all_entry_points.select(group=PLUGIN_ENTRY_POINT):
         CUSTOM_EVALS[ep.name] = ep.load()
